@@ -214,7 +214,9 @@ xfce_spawn_get_active_workspace_number (GdkScreen *screen)
   gint       format_ret;
   gint       ws_num = 0;
 
-  gdk_error_trap_push ();
+  GdkDisplay *display;
+  display = gdk_screen_get_display (screen);
+  gdk_x11_display_error_trap_push (display);
 
   root = gdk_screen_get_root_window (screen);
 
@@ -249,12 +251,7 @@ xfce_spawn_get_active_workspace_number (GdkScreen *screen)
       XFree (prop_ret);
     }
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-  gdk_error_trap_pop_ignored ();
-#else
-  if (gdk_error_trap_pop () != 0)
-    return 0;
-#endif
+  gdk_x11_display_error_trap_pop_ignored (display);
 
   return ws_num;
 }
@@ -365,7 +362,10 @@ xfce_spawn_on_screen_with_child_watch (GdkScreen    *screen,
     }
 
   /* add the real display name for the screen */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  /* TODO: Move xfwm_make_display_name to libxfce4ui */
   display_name = gdk_screen_make_display_name (screen);
+G_GNUC_END_IGNORE_DEPRECATIONS
   cenvp[n_cenvp++] = g_strconcat ("DISPLAY=", display_name, NULL);
   g_free (display_name);
 
@@ -373,9 +373,11 @@ xfce_spawn_on_screen_with_child_watch (GdkScreen    *screen,
   /* initialize the sn launcher context */
   if (G_LIKELY (startup_notify))
     {
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
       sn_display = sn_display_new (GDK_SCREEN_XDISPLAY (screen),
                                    (SnDisplayErrorTrapPush) (void (*)(void)) gdk_error_trap_push,
                                    (SnDisplayErrorTrapPop) (void (*)(void)) gdk_error_trap_pop);
+G_GNUC_END_IGNORE_DEPRECATIONS
 
       if (G_LIKELY (sn_display != NULL))
         {
