@@ -37,12 +37,15 @@
 #endif
 
 #define MARGIN 20
+#define DOCS_URL "https://docs.xfce.org/xfce/"
+#define DOCS_URL_SLUG "/start"
 
 
 
 typedef struct
 {
   const gchar *name;
+  const gchar *icon_name;
   const gchar *display_name;
   const gchar *description;
 }
@@ -111,116 +114,110 @@ xfce_about_system (GtkBuilder *builder)
 
 
 static void
-xfce_about_about (GtkTextBuffer *buffer)
+xfce_about_about (GtkWidget *vbox)
 {
   guint                i;
   AboutModules        *info;
-  GtkTextTag          *bold;
-  GtkTextTag          *indent;
-  GtkTextIter          end;
-  gchar               *str;
   static AboutModules  xfce_about_info[] =
     {
       { "xfwm4",
+        "org.xfce.xfwm4",
         N_("Window Manager"),
         N_("Handles the placement of windows on the screen.")
       },
       { "xfce4-panel",
+        "org.xfce.panel",
         N_("Panel"),
-        N_("Program launchers, window buttons, applications menu, "
-           "workspace switcher and more.")
+        N_("Provides a home for window buttons, launchers, app menu and more.")
       },
       { "xfdesktop",
+        "org.xfce.xfdesktop",
         N_("Desktop Manager"),
-        N_("Sets the background color or image with optional application menu "
-           "or icons for minimized applications or launchers, devices and folders.")
+        N_("Sets desktop backgrounds, handles icons and more.")
       },
       { "thunar",
+        "org.xfce.thunar",
         N_("File Manager"),
-        N_("A modern file manager for the Unix/Linux desktop, aiming to "
-           "be easy-to-use and fast.")
+        N_("Manages your files in a modern, easy-to-use and fast way.")
       },
       { "thunar-volman",
+        "org.xfce.thunar-volman",
         N_("Volume manager"),
-        N_("Automatic management of removable drives and media for Thunar.")
+        N_("Manages removable drives and media for Thunar.")
       },
       { "xfce4-session",
+        "org.xfce.session",
         N_("Session Manager"),
-        N_("Restores your session on startup and allows you to shutdown "
-           "the computer from Xfce.")
+        N_("Saves and restores your session, handles startup, autostart and shutdown.")
       },
       { "xfce4-settings",
+        "org.xfce.settings",
         N_("Setting System"),
-        N_("Configuration system to control various aspects of the desktop "
-           "like appearance, display, keyboard and mouse settings.")
+        N_("Configures appearance, display, keyboard and mouse settings.")
       },
       { "xfce4-appfinder",
+        "org.xfce.appfinder",
         N_("Application Finder"),
-        N_("Shows the applications installed on your system in categories, "
-           "so you can quickly find and launch them.")
+        N_("Quickly finds and launches applications installed on your system.")
       },
       { "xfconf",
+        "org.xfce.settings.editor",
         N_("Settings Daemon"),
-        N_("D-Bus-based configuration storage system.")
+        N_("Stores your settings in a D-Bus-based configuration system.")
       },
       { "garcon",
+        "org.xfce.garcon",
         N_("A menu library"),
-        N_("A freedesktop.org compliant menu implementation based "
-           "on GLib and GIO.")
+        N_("Implements a freedesktop.org compliant menu based on GLib and GIO.")
       },
       { "tumbler",
+        "org.xfce.tumbler",
         N_("Thumbnails service"),
-        N_("Thumbnail service implementing the thumbnail management D-Bus specification.")
+        N_("Implements the thumbnail management D-Bus specification.")
       }
     };
 
-  g_return_if_fail (GTK_IS_TEXT_BUFFER (buffer));
-
-  gtk_text_buffer_insert_at_cursor (buffer,
-      _("Xfce is a collection of programs that together provide a "
-        "full-featured desktop environment. The following programs "
-        "are part of the Xfce core:"), -1);
-  gtk_text_buffer_get_end_iter (buffer, &end);
-
-  bold = gtk_text_buffer_create_tag (buffer, "bold",
-                                     "weight", PANGO_WEIGHT_BOLD, NULL);
-
-  indent = gtk_text_buffer_create_tag (buffer, "indent",
-                                       "left-margin", MARGIN, NULL);
+  g_return_if_fail (GTK_IS_BOX (vbox));
 
   for (i = 0; i < G_N_ELEMENTS (xfce_about_info); i++)
     {
+      GtkWidget     *grid;
+      GtkWidget     *image;
+      GtkWidget     *component;
+      GtkWidget     *description;
+      const gchar   *format;
+      gchar         *str;
+
       info = xfce_about_info + i;
+      format = "<b>%s</b> (<a href='%s%s%s'>%s</a>)";
+      str = g_markup_printf_escaped (format, _(info->display_name), DOCS_URL,
+                                     info->name, DOCS_URL_SLUG, info->name);
+
+      component = gtk_label_new (NULL);
+      gtk_label_set_markup (GTK_LABEL (component), str);
+      gtk_label_set_xalign (GTK_LABEL (component), 0.0);
+      gtk_label_set_line_wrap (GTK_LABEL (component), TRUE);
+      gtk_widget_set_valign (GTK_WIDGET (component), GTK_ALIGN_END);
+
+      description = gtk_label_new (_(info->description));
+      gtk_label_set_xalign (GTK_LABEL (description), 0.0);
+      gtk_label_set_line_wrap (GTK_LABEL (description), TRUE);
+      gtk_widget_set_valign (GTK_WIDGET (description), GTK_ALIGN_START);
+
+      image = gtk_image_new_from_icon_name (info->icon_name, GTK_ICON_SIZE_DND);
+
+      grid = gtk_grid_new ();
+      gtk_grid_set_column_spacing (GTK_GRID (grid), 12);
+      gtk_grid_set_row_spacing (GTK_GRID (grid), 3);
+      gtk_grid_attach (GTK_GRID (grid), image, 0, 0, 1, 2);
+      gtk_grid_attach (GTK_GRID (grid), component, 1, 0, 1, 1);
+      gtk_grid_attach (GTK_GRID (grid), description, 1, 1, 1, 1);
+      gtk_widget_show_all (grid);
+
+      gtk_container_add (GTK_CONTAINER (vbox), grid);
 
-      str = g_strdup_printf ("\n\n%s (%s)\n", _(info->display_name), info->name);
-      gtk_text_buffer_insert_with_tags (buffer, &end, str, -1, bold, NULL);
       g_free (str);
-
-      gtk_text_buffer_insert_with_tags (buffer, &end, _(info->description), -1, indent, NULL);
     }
-
-  gtk_text_buffer_insert (buffer, &end, "\n\n", -1);
-  gtk_text_buffer_insert (buffer, &end,
-      _("Xfce is also a development platform providing several libraries, "
-        "that help programmers create applications that fit in well "
-        "with the desktop environment."), -1);
-
-  gtk_text_buffer_insert (buffer, &end, "\n\n", -1);
-  gtk_text_buffer_insert (buffer, &end,
-      _("Xfce components are licensed under free or open source "
-        "licences; GPL or BSDL for applications and LGPL or BSDL for "
-        "libraries. Look at the documentation, the source code or the "
-        "Xfce website (https://www.xfce.org) for more information."), -1);
-
-  gtk_text_buffer_insert (buffer, &end, "\n\n", -1);
-  gtk_text_buffer_insert (buffer, &end,
-      _("Thank you for your interest in Xfce."), -1);
-
-  gtk_text_buffer_insert (buffer, &end, "\n\n\t- ", -1);
-  gtk_text_buffer_insert (buffer, &end,
-      _("The Xfce Development Team"), -1);
-
-  gtk_text_buffer_insert (buffer, &end, "\n", -1);
 }
 
 
@@ -565,8 +562,8 @@ main (gint    argc,
   gtk_notebook_remove_page (GTK_NOTEBOOK (gtk_builder_get_object (builder, "notebook")), 0);
 #endif
 
-  object = gtk_builder_get_object (builder, "about-buffer");
-  xfce_about_about (GTK_TEXT_BUFFER (object));
+  object = gtk_builder_get_object (builder, "components-box");
+  xfce_about_about (GTK_WIDGET (object));
 
   object = gtk_builder_get_object (builder, "credits-buffer");
   xfce_about_credits (GTK_TEXT_BUFFER (object));
